@@ -198,8 +198,8 @@ class StaticFiles(Resource):
         if dir3 is not None:
           filePath = "%s/%s" % (filePath, dir3)
     if filePath in [
-      "index.html", "o2c.html", "swagger-ui.js"
-       "swagger-ui.min", "lib/swagger-oauth.js"]:
+      "index.html", "o2c.html", "swagger-ui.js",
+       "swagger-ui.min.js", "lib/swagger-oauth.js"]:
       conf = {'resource_list_url': req_registry['spec_endpoint_path']}
       return render_page(filePath, conf)
     mime = 'text/plain'
@@ -213,7 +213,7 @@ class StaticFiles(Resource):
       mime = 'text/css'
     filePath = os.path.join(rootPath, 'static', filePath)
     if os.path.exists(filePath):
-      fs = open(filePath, "r")
+      fs = open(filePath, "rb")
       return Response(fs, mimetype=mime)
     abort(404)
 
@@ -300,7 +300,7 @@ class SwaggerEndpoint(object):
               op['parameters'] = merge_parameter_list(
                 op['parameters'], att_value)
             else:
-              if att_name in op:
+              if att_name in op and att_name is not 'nickname':
                 att_value = '{0}<br/>{1}'.format(att_value, op[att_name])
               op[att_name] = att_value
           elif isinstance(att_value, object):
@@ -411,7 +411,8 @@ def add_model(model_class):
       defaults = list(
         zip(argspec.args[-len(argspec.defaults):], argspec.defaults))
     properties = model['properties'] = {}
-    for arg in argspec.args[:-len(defaults)]:
+    required_args_count = len(argspec.args) - len(defaults)
+    for arg in argspec.args[:required_args_count]:
       required.append(arg)
       # type: string for lack of better knowledge, until we add more metadata
       properties[arg] = {'type': 'string'}
